@@ -21,29 +21,27 @@
 # A value of "1" means that if the new shading value is increased instead of decreased in place of the old one,
 # the change is not executed.
 
-#$computype = "linear";
+$computype = "linear";
 # TYPES OF CALCULATIONS FOR CALCULATING THE IRRADIANCE FACTORS.
 # (SEE SUBROUTINE "compareirrs".)
 # OPTIONS: "linear", "quadratic", "root".
-# THE LATTER TWO OPTIONS ARE OBSOLETE. ONLY "linear will remain".
+# THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE. ONLY "linear will remain".
 # WHEN UNSPECIFIED, THE DEFAULT IS "linear".
 
-@calcprocedures = ( "complete" );
-# Some options are the following:
-# "simplified", "incomplete", "basic", "main", "alternative", "complete", "maincomplete", spreaddiff".
-# THEY DIFFER IN HOW DIRECT RADIATION IS DISTINGUISHED FROM INDIRECT RADIATION.
-# ANOTHER OPTION IS "unified", WHICH HAS AN INFLUENCE ON THE WAY THE IRRADIANCE RATIOS ARE CALCULATED.
-# ONE MORE OPTION IS "wipeins", WHiCH WIPES OUT THE INSOLATION VALUES IN THE ISH FILES AFTER THE NEW
-# SHADING VALUES HAVE BEEN COMPUTED.
-# "alternative", "basic", "spreaddiff" AND HAVE BEEN DISCARDED AND BECOME OBSOLETE.
-# "basic" COULD BE ONLY USED IN PLACE OF "alternative".
-# "spreaddiff" CAN'T BE USED ALONE.
-# WITH THE "complete" AND "main" OPTIONS, BOTH $bounceambnum AND $bouncemaxnum MUST BE ASSIGNED A VALUE OTHER THAN 0.
+@calcprocedures = ( "complete", "halved" );
+# The options are the following:
+# "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff", "halved".
+# "main", "alternative", "complete" and "spreaddiff" can be combined with the other options. 
+# The others can't. "basic" also can be combined with the others: it can be used in place of "alternative".
+# "spreaddiff"c CAN'T BE USED ALONE.
+# THE "incomplete" OPTION IS UNSATISFACTORY AND ON THE WAY TO BECOME OBSOLETE.
+# MORE THAN ONE OPTION MAY CO-EXIST.
+# WITH THE "complete", "alternative" and "main" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
 # WHEN NO @calcprocedures VALUE IS PRESENT, THE PROGRAM DEFAULTS TO "simplified".
 
-%specularratios = ( reflector => 1 );
+%specularratios = ( reflector => 0 );
 #%specularratios = ( totaldirect => 1 );
-#%specularratios = ( reflector => 0 );
+#%specularratios = ( reflector => 1 );
 # THE VALUE OF EACH OF THESE KEY-VALUE PAIRS CONSTITUTES THE PROPORTION OF THE SPECULAR REFLECTIVITY
 # IF THE DIFFUSE REFLECTIVITY IS 1 FOR A MATERIAL ATTRIBUTED TO AN OBSTRUCTION. 
 # THE KEY OF THE VALUE IS CONSTITUTED BY THE NAME OF THAT MATERIAL.
